==> jc-1.4.0.tar.gz: gnu/xml/libxmlj/transform/ErrorListenerErrorHandler.h <==
// class gnu.xml.libxmlj.transform.ErrorListenerErrorHandler

// class file dependencies
// @dep_class f0990daa01704190 gnu_xml_libxmlj_transform_ErrorListenerErrorHandler
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler_H_
#define _JC_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_xml_transform_ErrorListener$object;
struct _jc_javax_xml_transform_TransformerException$object;
struct _jc_org_xml_sax_SAXException$object;
struct _jc_org_xml_sax_SAXParseException$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$sub_refs	_jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$sub_nonrefs	_jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$refs	_jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$refs;
typedef struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$nonrefs	_jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$object	_jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$object;

typedef const struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$vmethods	_jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$vtable	_jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$vtable;
typedef const struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$vtype	_jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$method$_init$876227f7f151acd7(_jc_env *, struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$object *, struct _jc_object *);

// Virtual methods
extern void _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$method$error$7d923204368685db(_jc_env *, struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$object *, struct _jc_org_xml_sax_SAXParseException$object *);
extern void _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$method$fatalError$52809331a66c9498(_jc_env *, struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$object *, struct _jc_org_xml_sax_SAXParseException$object *);
extern struct _jc_org_xml_sax_SAXException$object *_jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$method$getSAXException$1fdb6b2c5d77ff9a(_jc_env *, struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$object *, struct _jc_javax_xml_transform_TransformerException$object *);
extern void _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$method$warning$72c08df791ab6f01(_jc_env *, struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$object *, struct _jc_org_xml_sax_SAXParseException$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$method_info$error$7d923204368685db;
extern _jc_method _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$method_info$fatalError$52809331a66c9498;
extern _jc_method _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$method_info$getSAXException$1fdb6b2c5d77ff9a;
extern _jc_method _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$method_info$warning$72c08df791ab6f01;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$vmethods {
	void	(*error$7d923204368685db)(_jc_env *, struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$object *, struct _jc_org_xml_sax_SAXParseException$object *);
	void	(*fatalError$52809331a66c9498)(_jc_env *, struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$object *, struct _jc_org_xml_sax_SAXParseException$object *);
	struct _jc_org_xml_sax_SAXException$object	*(*getSAXException$1fdb6b2c5d77ff9a)(_jc_env *, struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$object *, struct _jc_javax_xml_transform_TransformerException$object *);
	void	(*warning$72c08df791ab6f01)(_jc_env *, struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$object *, struct _jc_org_xml_sax_SAXParseException$object *);
};

// Vtable
struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$vmethods	gnu_xml_libxmlj_transform_ErrorListenerErrorHandler;
};

// Vtype
struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$sub_refs {
	struct _jc_object	*listener;
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$refs {
    _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$sub_refs	gnu_xml_libxmlj_transform_ErrorListenerErrorHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$sub_nonrefs	gnu_xml_libxmlj_transform_ErrorListenerErrorHandler;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$object {
	_jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$vtype	*vtype;
	_jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$vtype _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_transform_ErrorListenerErrorHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$class_object;

#endif	/* _JC_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/libxmlj/transform/ErrorListenerErrorHandler.h <==
// class gnu.xml.libxmlj.transform.ErrorListenerErrorHandler

// class file dependencies
// @dep_class f0990daa01704190 gnu_xml_libxmlj_transform_ErrorListenerErrorHandler
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler_H_
#define _JC_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_xml_transform_ErrorListener$object;
struct _jc_javax_xml_transform_TransformerException$object;
struct _jc_org_xml_sax_SAXException$object;
struct _jc_org_xml_sax_SAXParseException$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$sub_refs	_jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$sub_nonrefs	_jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$refs	_jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$refs;
typedef struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$nonrefs	_jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$object	_jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$object;

typedef const struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$vmethods	_jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$vtable	_jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$vtable;
typedef const struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$vtype	_jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$method$_init$876227f7f151acd7(_jc_env *, struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$method$error$7d923204368685db(_jc_env *, struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$object *, struct _jc_org_xml_sax_SAXParseException$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$method$fatalError$52809331a66c9498(_jc_env *, struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$object *, struct _jc_org_xml_sax_SAXParseException$object *) _JC_JCNI_ATTR;
extern struct _jc_org_xml_sax_SAXException$object *_jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$method$getSAXException$1fdb6b2c5d77ff9a(_jc_env *, struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$object *, struct _jc_javax_xml_transform_TransformerException$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$method$warning$72c08df791ab6f01(_jc_env *, struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$object *, struct _jc_org_xml_sax_SAXParseException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$method_info$error$7d923204368685db;
extern _jc_method _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$method_info$fatalError$52809331a66c9498;
extern _jc_method _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$method_info$getSAXException$1fdb6b2c5d77ff9a;
extern _jc_method _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$method_info$warning$72c08df791ab6f01;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$vmethods {
	void	(*error$7d923204368685db)(_jc_env *, struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$object *, struct _jc_org_xml_sax_SAXParseException$object *) _JC_JCNI_ATTR;
	void	(*fatalError$52809331a66c9498)(_jc_env *, struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$object *, struct _jc_org_xml_sax_SAXParseException$object *) _JC_JCNI_ATTR;
	struct _jc_org_xml_sax_SAXException$object	*(*getSAXException$1fdb6b2c5d77ff9a)(_jc_env *, struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$object *, struct _jc_javax_xml_transform_TransformerException$object *) _JC_JCNI_ATTR;
	void	(*warning$72c08df791ab6f01)(_jc_env *, struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$object *, struct _jc_org_xml_sax_SAXParseException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$vmethods	gnu_xml_libxmlj_transform_ErrorListenerErrorHandler;
};

// Vtype
struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$sub_refs {
	struct _jc_object	*listener;
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$refs {
    _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$sub_refs	gnu_xml_libxmlj_transform_ErrorListenerErrorHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$sub_nonrefs	gnu_xml_libxmlj_transform_ErrorListenerErrorHandler;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$object {
	_jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$vtype	*vtype;
	_jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$vtype _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_transform_ErrorListenerErrorHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler$class_object;

#endif	/* _JC_gnu_xml_libxmlj_transform_ErrorListenerErrorHandler_H_ */
